==> zio-aws-kafka_2.13-5.17.104.2-sources.jar: zio/aws/kafka/model/CreateConfigurationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.{__blob, __string}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateConfigurationRequest(
    description: Option[__string] = None,
    kafkaVersions: Option[Iterable[__string]] = None,
    name: __string,
    serverProperties: __blob
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest = {
    import CreateConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
      .builder()
      .optionallyWith(
        description.map(value => __string.unwrap(value): java.lang.String)
      )(_.description)
      .optionallyWith(
        kafkaVersions.map(value =>
          value.map { item =>
            __string.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.kafkaVersions)
      .name(__string.unwrap(name): java.lang.String)
      .serverProperties(
        software.amazon.awssdk.core.SdkBytes
          .fromByteArrayUnsafe(serverProperties.toArray[Byte])
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.CreateConfigurationRequest.ReadOnly =
    zio.aws.kafka.model.CreateConfigurationRequest.wrap(buildAwsValue())
}
object CreateConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.CreateConfigurationRequest =
      zio.aws.kafka.model.CreateConfigurationRequest(
        description.map(value => value),
        kafkaVersions.map(value => value),
        name,
        serverProperties
      )
    def description: Option[__string]
    def kafkaVersions: Option[List[__string]]
    def name: __string
    def serverProperties: __blob
    def getDescription: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("description", description)
    def getKafkaVersions: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("kafkaVersions", kafkaVersions)
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
    def getServerProperties: ZIO[Any, Nothing, __blob] =
      ZIO.succeed(serverProperties)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
  ) extends zio.aws.kafka.model.CreateConfigurationRequest.ReadOnly {
    override val description: Option[__string] = scala
      .Option(impl.description())
      .map(value => zio.aws.kafka.model.primitives.__string(value))
    override val kafkaVersions: Option[List[__string]] = scala
      .Option(impl.kafkaVersions())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kafka.model.primitives.__string(item)
        }.toList
      )
    override val name: __string =
      zio.aws.kafka.model.primitives.__string(impl.name())
    override val serverProperties: __blob = zio.aws.kafka.model.primitives
      .__blob(zio.Chunk.fromArray(impl.serverProperties().asByteArrayUnsafe()))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
  ): zio.aws.kafka.model.CreateConfigurationRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.17.151.2-sources.jar: zio/aws/kafka/model/CreateConfigurationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.{__blob, __string}
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateConfigurationRequest(
    description: Option[__string] = None,
    kafkaVersions: Option[Iterable[__string]] = None,
    name: __string,
    serverProperties: __blob
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest = {
    import CreateConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
      .builder()
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        kafkaVersions.map(value =>
          value.map { item =>
            item: java.lang.String
          }.asJavaCollection
        )
      )(_.kafkaVersions)
      .name(name: java.lang.String)
      .serverProperties(
        software.amazon.awssdk.core.SdkBytes
          .fromByteArrayUnsafe(serverProperties.toArray[Byte])
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.CreateConfigurationRequest.ReadOnly =
    zio.aws.kafka.model.CreateConfigurationRequest.wrap(buildAwsValue())
}
object CreateConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.CreateConfigurationRequest =
      zio.aws.kafka.model.CreateConfigurationRequest(
        description.map(value => value),
        kafkaVersions.map(value => value),
        name,
        serverProperties
      )
    def description: Option[__string]
    def kafkaVersions: Option[List[__string]]
    def name: __string
    def serverProperties: __blob
    def getDescription: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("description", description)
    def getKafkaVersions: ZIO[Any, AwsError, List[__string]] =
      AwsError.unwrapOptionField("kafkaVersions", kafkaVersions)
    def getName: ZIO[Any, Nothing, __string] = ZIO.succeed(name)
    def getServerProperties: ZIO[Any, Nothing, __blob] =
      ZIO.succeed(serverProperties)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
  ) extends zio.aws.kafka.model.CreateConfigurationRequest.ReadOnly {
    override val description: Option[__string] =
      scala.Option(impl.description()).map(value => value: __string)
    override val kafkaVersions: Option[List[__string]] = scala
      .Option(impl.kafkaVersions())
      .map(value =>
        value.asScala.map { item =>
          item: __string
        }.toList
      )
    override val name: __string = impl.name(): __string
    override val serverProperties: __blob =
      zio.Chunk.fromArray(impl.serverProperties().asByteArrayUnsafe()): __blob
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.CreateConfigurationRequest
  ): zio.aws.kafka.model.CreateConfigurationRequest.ReadOnly = new Wrapper(impl)
}
